#!/opt/concourse/worker/volumes/live/d3c0a23d-6bf8-4850-4a86-64a133966dfb/volume/anaconda-navigator_1626167524212/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh/Anaconda-Navigator.app/Contents/MacOS/python
from subprocess import call

call(["/opt/concourse/worker/volumes/live/d3c0a23d-6bf8-4850-4a86-64a133966dfb/volume/anaconda-navigator_1626167524212/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh/bin/anaconda-navigator"])
